<p align="center">
    <a href="https://synnaxlabs.com/">
        <img src="../../x/media/static/logo/icon-white-padded.png" width="20%"/>
    </a>
</p>

# Synnax Python Client and CLI

This directory contains the source code for the Synnax Python client library. For
practical guides on using it to communicate with a cluster, see the
[Synnax documentation](https://docs.synnaxlabs.com/).

For code examples, see the [examples directory](examples/).

## Installation

The Synnax Python client is available on PyPI. To install it, run:

```bash
pip install synnax
```

## Contributing

Read both the [Synnax Contribution Guide](../../docs/CONTRIBUTING.md) and the
[Python Client Contribution Guide](CONTRIBUTING.md) to learn about the codebase and our
process for working with it.
